@@ -1,5 +1,5 @@
 package Thrift::API::HiveClient2;
-$Thrift::API::HiveClient2::VERSION = '0.025';
+$Thrift::API::HiveClient2::VERSION = '0.026';
 {
   $Thrift::API::HiveClient2::DIST = 'Thrift-API-HiveClient2';
 }
@@ -16,7 +16,6 @@ use List::MoreUtils 'zip';
 
 use Thrift;
 use Thrift::Socket;
-use Thrift::SSLSocket;
 use Thrift::BufferedTransport;
 
 # Protocol loading is done dynamically later.
@@ -138,13 +137,15 @@ sub BUILD {
 
     my $thrift_socket;
     
+    my $transport_class = 'Thrift::Socket';
     if( $self->use_ssl ) {
-     $thrift_socket = Thrift::SSLSocket->new( $self->host, $self->port );
-    }
-    else {
-     $thrift_socket = Thrift::Socket->new( $self->host, $self->port );
+        require Thrift::SSLSocket;
+        $transport_class = 'Thrift::SSLSocket';
     }
 
+    $thrift_socket = $transport_class->new( $self->host, $self->port );
+
+
     $self->_set_socket( $thrift_socket )
         unless $self->_socket;
     $self->_socket->setRecvTimeout( $self->timeout * 1000 );
@@ -547,7 +548,7 @@ Thrift::API::HiveClient2 - Perl to HiveServer2 Thrift API wrapper
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =for Pod::Coverage BUILD DEMOLISH
 
